@@ -43,13 +43,13 @@ class PageDestinations : public GenericPage
 {
     Q_OBJECT
 public:
-    explicit PageDestinations(const QVariantHash &args = QVariantHash(), QWidget *parent = 0);
-    ~PageDestinations();
+    explicit PageDestinations(const QVariantHash &args = QVariantHash(), QWidget *parent = nullptr);
+    ~PageDestinations() override;
 
-    bool canProceed() const Q_DECL_OVERRIDE;
-    void setValues(const QVariantHash &args) Q_DECL_OVERRIDE;
-    QVariantHash values() const Q_DECL_OVERRIDE;
-    bool isValid() const Q_DECL_OVERRIDE;
+    bool canProceed() const override;
+    void setValues(const QVariantHash &args) override;
+    QVariantHash values() const override;
+    bool isValid() const override;
 
 private slots:
     void deviceChanged();
