@@ -31,7 +31,7 @@ class Q_DECL_EXPORT JobSortFilterModel : public QSortFilterProxyModel
     Q_PROPERTY(int activeCount READ activeCount NOTIFY activeCountChanged)
     Q_PROPERTY(int count READ count NOTIFY countChanged)
 public:
-    explicit JobSortFilterModel(QObject *parent = 0);
+    explicit JobSortFilterModel(QObject *parent = nullptr);
 
     void setModel(QAbstractItemModel *model);
     void setFilteredPrinters(const QString &printers);
@@ -45,8 +45,8 @@ signals:
     void filteredPrintersChanged();
 
 private:
-    bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const Q_DECL_OVERRIDE;
-    bool lessThan(const QModelIndex &left, const QModelIndex &right) const Q_DECL_OVERRIDE;
+    bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override;
+    bool lessThan(const QModelIndex &left, const QModelIndex &right) const override;
 
     int weightForState(int state) const;
 
